package com.ecyrd.jspwiki.plugin;

import java.util.HashMap;

import org.jboss.wiki.WikiInsidePlugin;
import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiSession;
import org.jboss.wiki.plugins.HTMLTranslatorParts;

public class ImagePlugin extends WikiInsidePlugin {

	@Override
	public String process(WikiPage wikiPage, WikiSession wikiSession,
			HashMap<String, String> attributes) {
	/*
    * src = Image source. This can either be a full URL (http://...) or a WikiAttachment? name. Required.
    * align = left|right|center. The image alignment.
    * height = integer. Force the height of the image.
    * width = integer. Force the width of the image.
    * alt = alt text. The alt text of an image. This is very useful when doing 
    * pages that can be navigated with text-only browsers
    * caption = caption text. The text that should be shown as a caption under the image.
    * link = hyperlink. A hyperlink (http://...). In the future, you can also use WikiPages?.
    * border = integer. Size of the image border.
    * style = style info. Any style markup you would like to apply to the table surrounding the image.
    * class = class name. Redefine the default class for this image, which is "imageplugin".
    */
		
		String src = attributes.get("src");
		
		if (src == null) {
			return "<i>Image Plugin Error: \"src\" value has to be set !</i>";
		}
		
		if (!HTMLTranslatorParts.isExternalLink(src)) {
			src = wikiSession.getAttribute("hostURL") + "/wiki/" + src;
		}
		
		String align = attributes.get("align");
		String height = attributes.get("height");
		String width = attributes.get("width");
		String alt = attributes.get("alt");
		String caption = attributes.get("caption");
		String link = attributes.get("link");
		String border = attributes.get("border");
		String style = attributes.get("style");
		String classAtr = attributes.get("class");
		
		StringBuffer imageLink = new StringBuffer();
		
		imageLink.append((caption != null) ? "<table><tr><td>" : "")
				 .append((link != null) ? "<a href=\""+link+"\">" : "")
				 .append("<img ")
				 .append("src=\"")
				 .append(src)
				 .append("\" ")
				 .append((align != null) ? "align"+align+"\" " : "")
				 .append((height != null) ? "height=\""+height+"\" " : "")
				 .append((width != null) ? "width=\""+width+"\" " : "")
				 .append((alt != null) ? "alt=\""+alt+"\" " : "")
				 .append((border != null) ? "border=\""+border+"\" " : "")
				 .append((style != null) ? "style=\""+style+"\" " : "")
				 .append("class=\""+((classAtr != null) ? classAtr : "imageplugin") + "\" ")
				 .append((link != null) ? "</a>" : "")
				 .append((caption != null) ? "</td></tr><tr><td style=\"text-align: center\">"+caption+"</td></tr></table>" : "");
		
		return imageLink.toString();
	}

	@Override
	public void init() {
		// TODO Auto-generated method stub

	}

	@Override
	public boolean processContent() {
		return false;
	}

}
