/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.util.Set;
import java.util.TreeSet;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.portlet.ActionRequest;
import javax.portlet.RenderRequest;
import javax.transaction.TransactionManager;

import org.jboss.logging.Logger;
import org.jboss.portal.common.transaction.TransactionException;
import org.jboss.portal.common.transaction.TransactionManagerProvider;
import org.jboss.portal.common.transaction.Transactions;
import org.jboss.portal.core.model.Role;
import org.jboss.portal.core.modules.ModuleException;
import org.jboss.portal.core.modules.RoleModule;
import org.jboss.portlet.JBossActionRequest;
import org.jboss.portlet.JBossRenderRequest;

public class JBossPortalCredentials extends Credentials {

	private final String adminRoleName = "Admin";

	private String name = null;

	private boolean logedIn = false;

	private boolean isAdmin = false;

	private Set<String> roles;

	private Set<Role> allRoles;

	private TransactionManager tm;
	
	private String email;

	private static final String roleModulesCtx = "java:portal/RoleModule";

	private Logger log = Logger.getLogger(this.getClass());

	public JBossPortalCredentials() {

	}

	public void setRenderRequest(RenderRequest rReq) {

	}

	public void setParam(Object param) {
		if (param instanceof JBossActionRequest) {
			JBossActionRequest jrReq = (JBossActionRequest) param;

			if (jrReq.getUser() != null) {
				name = jrReq.getUser().getUserName();
				logedIn = true;
				isAdmin = jrReq.getUser().getRoleNames()
						.contains(adminRoleName);
				roles = jrReq.getUser().getRoleNames();
				email = jrReq.getUser().getRealEmail();
			}

		} else if (param instanceof JBossRenderRequest) {
			JBossRenderRequest jrReq = (JBossRenderRequest) param;

			if (jrReq.getUser() != null) {
				name = jrReq.getUser().getUserName();
				logedIn = true;
				isAdmin = jrReq.getUser().getRoleNames()
						.contains(adminRoleName);
				roles = jrReq.getUser().getRoleNames();
				email = jrReq.getUser().getRealEmail();
			} else {
				name = "Unknown";
			}

			InitialContext initialContext;
			try {
				initialContext = new InitialContext();
				RoleModule roleModule = (RoleModule) initialContext
						.lookup(roleModulesCtx);

				try {
					allRoles = roleModule.findRoles();
				} catch (ModuleException e) {
					log.error("Couldn't get roles from portal", e);
				}

			} catch (NamingException e) {
				log.error(e);
			}

		} else {
			log.error("You are not running JBoss Portal");
		}
	}

	public String getName() {
		return name;
	}

	public boolean isAdmin() {
		return isAdmin;
	}
	private static final String userModuleCtx = "java:portal/UserModule";


	public boolean isLoggedIn() {
		return logedIn;
	}

	@Override
	public boolean isUserInRole(String role) {
		if (roles != null)
			return roles.contains(role);
		else
			return false;
	}

	@Override
	public Set<String> getAllRoles() {
		Set<String> roleNames = new TreeSet<String>();

		for (Role role : allRoles) {
			roleNames.add(role.getName());
		}

		return roleNames;
	}

	@Override
	public String getEmail() {
		return email;
	}

}
