/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.io.IOException;
import java.util.Set;
import java.util.TreeSet;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSession;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.jboss.logging.Logger;
import org.jboss.mx.util.MBeanProxyExt;
import org.jboss.mx.util.MBeanServerLocator;
import org.jboss.wiki.exceptions.WikiManagementNotFoundException;
import org.jboss.wiki.management.EMailNotifier;
import org.jboss.wiki.management.NotificationMsg;
import org.jboss.wiki.management.WikiServiceManagement;
import org.jboss.wiki.plugins.DifferenceEngine;
import org.jboss.wiki.plugins.WatchListPlugin;

/**
 * Commons class
 * 
 * @author <a href="mailto:tomasz.szymanski@jboss.com">Tomasz Szymanski</a>
 * 
 */
public class WikiCommon {

	public static final String wikiButtons = "!WikiButtons";

	public static final String WIKI_SERVICE_NAME = "wiki:service=wikiService";

	private static Logger log = Logger.getLogger(WikiCommon.class);

	private static WikiServiceManagement wikiServiceMenagement;

	public static WikiServiceManagement getWikiManagement()
			throws WikiManagementNotFoundException {
		try {
			if (wikiServiceMenagement == null)
				wikiServiceMenagement = (WikiServiceManagement) MBeanProxyExt
						.create(WikiServiceManagement.class, WIKI_SERVICE_NAME,
								MBeanServerLocator.locate());

			return wikiServiceMenagement;
		} catch (Exception e) {
			throw new WikiManagementNotFoundException(e);
		}
	}

	public static void sendNotificationMail(WikiPage page,
			WikiSession wikiSession, WikiEngine engine, String fromEmail) {
		try {
			InitialContext context = new InitialContext();

			// QueueSession sess = null;
			// Queue queue = null;
			EMailNotifier notifer = null;
			try {
				/*
				 * queue = (Queue) context.lookup("queue/wikiNotifications");
				 * QueueConnectionFactory factory = (QueueConnectionFactory)
				 * context .lookup("java:/ConnectionFactory"); sess =
				 * factory.createQueueConnection().createQueueSession( false,
				 * QueueSession.AUTO_ACKNOWLEDGE);
				 */

				notifer = (EMailNotifier) context.lookup(EMailNotifier.class
						.getName());

				// if (sess != null) {
				if (notifer != null) {
					String notifs = page
							.getMetaDataProperty(WatchListPlugin.WATCH_PROPERTY);

					String notifsGlobal = engine.getGlobalProperty(
							WatchListPlugin.WATCH_PROPERTY, page.getLangCode());

					if ((notifs != null && notifs.length() > 0)
							|| (notifsGlobal != null && notifsGlobal.length() > 0)) {
						Set<String> users = new TreeSet<String>();

						if (notifs != null) {
							String[] splitedUsers = notifs.split(";");

							for (int i = 1; i < splitedUsers.length; i += 2) {
								users.add(splitedUsers[i]);
							}
						}

						if (notifsGlobal != null) {
							String[] splitedUsers = notifsGlobal.split(";");

							for (int i = 1; i < splitedUsers.length; i += 2) {
								users.add(splitedUsers[i]);
							}
						}

						page = (WikiPage) page.clone();

						engine.refreshPage(page.getName(), page.getLangCode());

						WikiPage orgPage;
						
						if (page.getLastVersion() > 1) {
							orgPage = engine.getByName(page.getName(),
									null, page.getLastVersion() - 1, page
											.getLangCode());
						}
						else {
							orgPage = (WikiPage)page.clone();
						}

						WikiPage pageHtml = engine.getWikiType("htmlClear")
								.process(page, wikiSession);

						WikiPage link = (WikiPage) page.clone();
						link.setContent("[" + page.getName() + "]");

						String pageLink = engine.getWikiType("htmlClear")
								.process(link, wikiSession).getContent();

						DifferenceEngine differenceEngine = new DifferenceEngine(
								"UTF-8");

						String diffs = "<br />\n<br /><h2>Diff</h2>\n<hr />\n";
						try {
							diffs += differenceEngine
									.colorizeDiff(differenceEngine.makeDiff(
											orgPage.getContent(), page
													.getContent()));
						} catch (IOException e) {
							log.error(
									"Eroror generating diffs for email notifs",
									e);
						}

						NotificationMsg notifMsg = new NotificationMsg(
								users,
								diffs
										+ "<br /><hr />\n<br/>\nThis is notification of page: "
										+ pageLink + "<br/>\n"
										+ pageHtml.getContent(),
								page.getName(), fromEmail, pageLink);
						// ObjectMessage msg =
						// sess.createObjectMessage(notifMsg);
						// sess.createSender(queue).send(msg);
						notifer.sendNotification(notifMsg);
					}
				} else {
					log.error("Couldn't create queue session.");
				}
			} catch (CloneNotSupportedException e) {
				log.error(e);
			}/*
				 * catch (JMSException e) { log.error(e); }
				 */
		} catch (NamingException e1) {
			log.error(e1);
		}
	}
}
