/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki;

import java.util.Map;

import org.jboss.wiki.exceptions.PageRenamingException;

/**
 * @author <a href="mailto:tomasz.szymanski@jboss.com">Tomasz Szymanski</a>
 *
 */
public interface WikiPageDictionary {

	/**Return RealName of given UID - this is what will be shown on the page (what user gets)
	 * 
	 * @param uid uid to translate
	 * @return apropriate UID
	 */
	public String getRealName(String uid);
	
	/**Return UID of RealName (uid is what JBoss Wiki uses for unique recognition of a page)
	 * 
	 * @param realName realName to translate
	 * @return apropriate RealName
	 */
	public String getUid(String realName);
	
	/**Function that adds renaming for current page. You have to remember about all the consequences.
	 * 
	 * @param uid Uid of a page.
	 * @param newName New name of a page
	 * @throws PageRenamingException If there is page with "newName" etc.
	 */
	public void rename(String uid, String newName) throws PageRenamingException;
	
	/**
	 * @param uid
	 * @return True if there is mapping for given uid.
	 */
	public boolean uidInDictionary(String uid);
	
	/**
	 * @param realName
	 * @return True if there is mapping for given realName
	 */
	public boolean realNameInDictionary(String realName);
	
	/**Removes mapping for given page. If there is no mapping for a page UID = RealName.
	 * 
	 * @param uid
	 * @throws PageRenamingException
	 */
	public void removeDictForPage(String uid) throws PageRenamingException;
	
	/**Sets wikiEngine reference
	 * @param wikiEngine
	 */
	public void setWikiEngine(WikiEngine wikiEngine);

	/**Set language code for current dataSource.
	 * @param langCode code of the language
	 */
	public void setLanguageCode(String langCode);

	/**Get all mapings
	 * @return Map of UID -> RealName
	 */
	public Map<String, String> getRenameMapings();
}
