/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.plugins;

import java.util.HashMap;

import org.jboss.wiki.WikiInsidePlugin;
import org.jboss.wiki.WikiPage;
import org.jboss.wiki.WikiSession;

public class InsertPageInsidePlugin extends WikiInsidePlugin {

	@Override
	public String process(WikiPage wikiPage, WikiSession wikiSession,
			HashMap<String, String> attributes) {
		String ret = wikiPage.getContent();
		
		String page = attributes.get("page");
		
		String style = attributes.get("style");
		
		Integer maxlength = getNumericValue(attributes,"maxlength");
		
		
		if (page == null) {
			ret = "''There is no 'page' attribute which is mandatory for InsertPage plugin''";
		}
		else {
			WikiPage about = wikiEngine.getByName(page, null, wikiPage.getLangCode());
			
			ret = addStyle(addMaxLength(about.getContent(), page, maxlength),style);
		}
		
		return ret;
	}
	
	private String addMaxLength(String content, String pageName, Integer maxlength) {
		if (maxlength != null) {
			if (content.length() > maxlength) {
				boolean insideLink = false;
				
				int i = 0;
				
				for (i = 0; (i < maxlength || insideLink); i++) {
					if (content.charAt(i) == '[') {
						insideLink = true;
					}
					else if (insideLink && content.charAt(i) == ']') {
						insideLink = false;
					}
				}
				return content.substring(0,i)+" ... \\\\\n\\\\\n[More...|"+pageName+"]";
			}
		}
		
		return content;
	}

	private String addStyle(String content, String style) {
		if ((style != null)&&(style.length() > 0)) {
			return HTMLTranslatorParts.pagePartRegexEnd+"<div style=\""+style+"\">"+HTMLTranslatorParts.pagePartRegexStart+content+HTMLTranslatorParts.pagePartRegexEnd+"</div>"+HTMLTranslatorParts.pagePartRegexStart;
		}
		else
			return content;
	}
	
	@Override
	public void init() {
		// TODO Auto-generated method stub

	}

}
