/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wiki.plugins;

import org.jboss.wiki.WikiPage;

import org.jboss.wiki.WikiPlugin;
import org.jboss.wiki.WikiSession;

public class RSSPlugin extends WikiPlugin {

	private DifferenceEngine differenceEngine;

	private void addItem(StringBuilder rssFeed, String title, String link,
			String description) {
		rssFeed.append("<item>\n");
		rssFeed.append("<title>").append(title).append("</title>\n");
		rssFeed.append("<link>").append(link).append("</link>\n");
		rssFeed.append("<description>").append(description).append(
				"</description>\n");
		rssFeed.append("</item>\n");
	}

	@Override
	public WikiPage process(WikiPage wikiPage, WikiSession wikiSession) {
		StringBuilder rssFeed = new StringBuilder(
				"<!-- name=\"generator\" content=\"JBoss Wiki RSSPlugin\" -->\n");
		rssFeed.append("<rss version=\"0.92\">\n");
		rssFeed.append("<channel>\n");
		rssFeed.append("<title>JBoss Forge Wiki: " + wikiPage.getName()
				+ "</title>\n");
		rssFeed.append("<link>").append(
				(String) wikiSession.getAttribute("hostURL")).append("/wiki/")
				.append(
						wikiPage.getLangCode().equals(
								wikiEngine.defaultLangugeCode) ? "" : wikiPage
								.getLangCode().toLowerCase()
								+ "/").append(wikiPage.getName()).append(
						"</link>\n");
		rssFeed.append("<description>JBoss Wiki: " + wikiPage.getName()
				+ "</description>\n");
		rssFeed.append("<language>en</language>\n");

		for (int i = wikiPage.getLastVersion(); i > 0; i--) {
			String content;

			if (i > 1) {
				content = differenceEngine
						.makeDiff(
								wikiPage.getPageAtVersion(true, i)
										.getPageContent(),
								wikiPage.getPageAtVersion(true, i - 1)
										.getPageContent()).replaceAll("&",
								"&amp;").replaceAll("<", "&lt;").replaceAll(
								">", "&gt;").replaceAll("\n", "<br />\n");
			} else {
				content = "This is first version of the page so it doesn't have diff yet";
			}

			addItem(rssFeed, wikiPage.getName() + " rev: " + i,
					(String) wikiSession.getAttribute("hostURL")
							+ getProperty("wikiHome").replaceAll("&", "&amp;")
							+ "&amp;page=" + wikiPage.getName()
							+ "&amp;version=" + i + "&amp;language="
							+ wikiPage.getLangCode(), content);
		}

		rssFeed.append("</channel>\n</rss>\n");

		wikiPage.setContent(rssFeed.toString());

		return wikiPage;
	}

	@Override
	public void init() {
		differenceEngine = new DifferenceEngine("UTF-8");
	}

}
